@@ -1,11 +1,11 @@
 /*
 Liquid War 6 is a unique multiplayer wargame.
-Copyright (C)  2005, 2006  Christian Mauduit <ufoot@ufoot.org>
+Copyright (C)  2005, 2006, 2007  Christian Mauduit <ufoot@ufoot.org>
 
-This program is free software; you can redistribute it and/or
-modify it under the terms of the GNU General Public License
-as published by the Free Software Foundation; either version 2
-of the License, or (at your option) any later version.
+This program is free software; you can redistribute it and/or modify
+it under the terms of the GNU General Public License as published by
+the Free Software Foundation, either version 3 of the License, or
+(at your option) any later version.
 
 This program is distributed in the hope that it will be useful,
 but WITHOUT ANY WARRANTY; without even the implied warranty of
@@ -13,8 +13,8 @@ MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 GNU General Public License for more details.
 
 You should have received a copy of the GNU General Public License
-along with this program; if not, write to the Free Software
-Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
+along with this program.  If not, see <http://www.gnu.org/licenses/>.
+
 
 Liquid War 6 homepage : http://www.gnu.org/software/liquidwar6/
 Contact author        : ufoot@ufoot.org
@@ -28,7 +28,7 @@ Contact author        : ufoot@ufoot.org
 
 #define BACKEND_DEVEL_NB_DEPTHS 4
 #define BACKEND_DEVEL_PATH_FORMAT "%ssrc/lib/%s/mod-%s/.libs/libmod_%s-%s.so"
-#define BACKEND_INSTALLED_PATH_FORMAT LIBDIR "/liquidwar6%s/libmod_%s-%s.so"
+#define BACKEND_INSTALLED_PATH_FORMAT LIBDIR "/liquidwar6/%s/libmod_%s-%s.so"
 
 static char *
 make_devel_backend_path (char *top_level_lib, char *backend_name, int depth)
