@@ -1,11 +1,11 @@
 /*
   Liquid War 6 is a unique multiplayer wargame.
-  Copyright (C)  2005, 2006  Christian Mauduit <ufoot@ufoot.org>
+  Copyright (C)  2005, 2006, 2007  Christian Mauduit <ufoot@ufoot.org>
 
-  This program is free software; you can redistribute it and/or
-  modify it under the terms of the GNU General Public License
-  as published by the Free Software Foundation; either version 2
-  of the License, or (at your option) any later version.
+  This program is free software; you can redistribute it and/or modify
+  it under the terms of the GNU General Public License as published by
+  the Free Software Foundation, either version 3 of the License, or
+  (at your option) any later version.
 
   This program is distributed in the hope that it will be useful,
   but WITHOUT ANY WARRANTY; without even the implied warranty of
@@ -13,8 +13,8 @@
   GNU General Public License for more details.
 
   You should have received a copy of the GNU General Public License
-  along with this program; if not, write to the Free Software
-  Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
+  along with this program.  If not, see <http://www.gnu.org/licenses/>.
+  
 
   Liquid War 6 homepage : http://www.gnu.org/software/liquidwar6/
   Contact author        : ufoot@ufoot.org
@@ -37,18 +37,18 @@ to_0str (SCM string)
   char *c_string;
   int length;
 
-  SCM_ASSERT (SCM_STRINGP (string), string, SCM_ARG1, "");
+  SCM_ASSERT (scm_is_string (string), string, SCM_ARG1, "");
 
   /*
    * See the comment in sys/sys-str.c to see why we use
    * 2 trailing '\0' at the end of the string.
    */
-  length = SCM_STRING_LENGTH (string);
+  length = scm_c_string_length (string);
   c_string = (char *) LW6SYS_MALLOC ((length + 2) * sizeof (char));
 
   if (c_string)
     {
-      memcpy ((void *) c_string, (void *) SCM_STRING_CHARS (string),
+      memcpy ((void *) c_string, (void *) scm_i_string_chars (string),
 	      length * sizeof (char));
       c_string[length] = c_string[length + 1] = '\0';
     }
@@ -71,7 +71,7 @@ scm_gettext (SCM string)
   char *c_string;
   SCM ret;
 
-  SCM_ASSERT (SCM_STRINGP (string), string, SCM_ARG1, "c-gettext");
+  SCM_ASSERT (scm_is_string (string), string, SCM_ARG1, "c-gettext");
 
   c_string = to_0str (string);
   if (c_string)
@@ -101,10 +101,10 @@ scm_lw6sys_log (SCM level, SCM message)
   int c_level;
   char *c_message;
 
-  SCM_ASSERT (SCM_INUMP (level), level, SCM_ARG1, "c-lw6sys-log");
-  SCM_ASSERT (SCM_STRINGP (message), message, SCM_ARG2, "c-lw6sys-log");
+  SCM_ASSERT (scm_is_integer (level), level, SCM_ARG1, "c-lw6sys-log");
+  SCM_ASSERT (scm_is_string (message), message, SCM_ARG2, "c-lw6sys-log");
 
-  c_level = SCM_INUM (level);
+  c_level = scm_to_int (level);
   c_message = to_0str (message);
   if (c_message)
     {
@@ -200,7 +200,7 @@ scm_lw6cfg_load (SCM filename)
     {
       char *c_filename;
 
-      SCM_ASSERT (SCM_STRINGP (filename),
+      SCM_ASSERT (scm_is_string (filename),
 		  filename, SCM_ARG1, "c-lw6cfg-load");
 
       c_filename = to_0str (filename);
@@ -241,7 +241,8 @@ scm_lw6cfg_option_exists (SCM key)
     {
       char *c_key;
 
-      SCM_ASSERT (SCM_STRINGP (key), key, SCM_ARG1, "c-lw6cfg-option-exists");
+      SCM_ASSERT (scm_is_string (key), key, SCM_ARG1,
+		  "c-lw6cfg-option-exists");
 
       c_key = to_0str (key);
       if (c_key)
@@ -278,7 +279,7 @@ scm_lw6cfg_get_option (SCM key)
     {
       char *c_key;
 
-      SCM_ASSERT (SCM_STRINGP (key), key, SCM_ARG1, "c-lw6cfg-get-option");
+      SCM_ASSERT (scm_is_string (key), key, SCM_ARG1, "c-lw6cfg-get-option");
 
       c_key = to_0str (key);
       if (c_key)
@@ -320,9 +321,9 @@ scm_lw6cfg_set_option (SCM key, SCM value)
       char *c_key;
       char *c_value;
 
-      SCM_ASSERT (SCM_STRINGP (key), key, SCM_ARG1, "c-lw6cfg-set-option");
+      SCM_ASSERT (scm_is_string (key), key, SCM_ARG1, "c-lw6cfg-set-option");
 
-      SCM_ASSERT (SCM_STRINGP (value),
+      SCM_ASSERT (scm_is_string (value),
 		  value, SCM_ARG2, "c-lw6cfg-set-option");
 
       c_key = to_0str (key);
@@ -354,7 +355,7 @@ scm_lw6cfg_save (SCM filename)
     {
       char *c_filename;
 
-      SCM_ASSERT (SCM_STRINGP (filename),
+      SCM_ASSERT (scm_is_string (filename),
 		  filename, SCM_ARG1, "c-lw6cfg-save");
 
       c_filename = to_0str (filename);
@@ -450,7 +451,7 @@ scm_lw6opt_static_get_int (SCM game_struct, SCM key)
 		  (lw6_global.smob_types.game_struct,
 		   game_struct), game_struct, SCM_ARG1,
 		  "c-lw6opt-static-get-int");
-      SCM_ASSERT (SCM_STRINGP (key), key, SCM_ARG2,
+      SCM_ASSERT (scm_is_string (key), key, SCM_ARG2,
 		  "c-lw6opt-static-get-int");
 
       c_game_struct = lw6_scm_to_game_struct (game_struct);
@@ -527,7 +528,7 @@ scm_lw6gfx_create_backend (SCM backend_name)
     {
       char *c_backend_name;
 
-      SCM_ASSERT (SCM_STRINGP (backend_name),
+      SCM_ASSERT (scm_is_string (backend_name),
 		  backend_name, SCM_ARG1, "c-lw6gfx-create-backend");
 
       c_backend_name = to_0str (backend_name);
@@ -581,7 +582,7 @@ scm_lw6gfx_display_background (SCM skin)
     {
       char *c_skin;
 
-      SCM_ASSERT (SCM_STRINGP (skin),
+      SCM_ASSERT (scm_is_string (skin),
 		  skin, SCM_ARG1, "c-lw6gfx-display-background");
 
       c_skin = to_0str (skin);
@@ -639,10 +640,10 @@ scm_lw6gfx_is_key_esc (SCM keysym)
     {
       int c_keysym;
 
-      SCM_ASSERT (SCM_INUMP (keysym), keysym, SCM_ARG1,
+      SCM_ASSERT (scm_is_integer (keysym), keysym, SCM_ARG1,
 		  "c-lw6gfx-is-key-esc");
 
-      c_keysym = SCM_INUM (keysym);
+      c_keysym = scm_to_int (keysym);
 
       ret =
 	lw6gfx_is_key_esc (lw6_global.gfx_backend,
@@ -665,9 +666,10 @@ scm_lw6gfx_is_key_up (SCM keysym)
     {
       int c_keysym;
 
-      SCM_ASSERT (SCM_INUMP (keysym), keysym, SCM_ARG1, "c-lw6gfx-is-key-up");
+      SCM_ASSERT (scm_is_integer (keysym), keysym, SCM_ARG1,
+		  "c-lw6gfx-is-key-up");
 
-      c_keysym = SCM_INUM (keysym);
+      c_keysym = scm_to_int (keysym);
 
       ret =
 	lw6gfx_is_key_up (lw6_global.gfx_backend,
@@ -690,10 +692,10 @@ scm_lw6gfx_is_key_down (SCM keysym)
     {
       int c_keysym;
 
-      SCM_ASSERT (SCM_INUMP (keysym), keysym, SCM_ARG1,
+      SCM_ASSERT (scm_is_integer (keysym), keysym, SCM_ARG1,
 		  "c-lw6gfx-is-key-down");
 
-      c_keysym = SCM_INUM (keysym);
+      c_keysym = scm_to_int (keysym);
 
       ret =
 	lw6gfx_is_key_down (lw6_global.gfx_backend,
@@ -716,10 +718,10 @@ scm_lw6gfx_is_key_left (SCM keysym)
     {
       int c_keysym;
 
-      SCM_ASSERT (SCM_INUMP (keysym), keysym, SCM_ARG1,
+      SCM_ASSERT (scm_is_integer (keysym), keysym, SCM_ARG1,
 		  "c-lw6gfx-is-key-left");
 
-      c_keysym = SCM_INUM (keysym);
+      c_keysym = scm_to_int (keysym);
 
       ret =
 	lw6gfx_is_key_left (lw6_global.gfx_backend,
@@ -742,10 +744,10 @@ scm_lw6gfx_is_key_right (SCM keysym)
     {
       int c_keysym;
 
-      SCM_ASSERT (SCM_INUMP (keysym), keysym, SCM_ARG1,
+      SCM_ASSERT (scm_is_integer (keysym), keysym, SCM_ARG1,
 		  "c-lw6gfx-is-key-right");
 
-      c_keysym = SCM_INUM (keysym);
+      c_keysym = scm_to_int (keysym);
 
       ret =
 	lw6gfx_is_key_right (lw6_global.gfx_backend,
@@ -768,10 +770,10 @@ scm_lw6gfx_is_key_enter (SCM keysym)
     {
       int c_keysym;
 
-      SCM_ASSERT (SCM_INUMP (keysym), keysym, SCM_ARG1,
+      SCM_ASSERT (scm_is_integer (keysym), keysym, SCM_ARG1,
 		  "c-lw6gfx-is-key-enter");
 
-      c_keysym = SCM_INUM (keysym);
+      c_keysym = scm_to_int (keysym);
 
       ret =
 	lw6gfx_is_key_enter (lw6_global.gfx_backend,
@@ -794,10 +796,10 @@ scm_lw6gfx_is_key_del (SCM keysym)
     {
       int c_keysym;
 
-      SCM_ASSERT (SCM_INUMP (keysym), keysym, SCM_ARG1,
+      SCM_ASSERT (scm_is_integer (keysym), keysym, SCM_ARG1,
 		  "c-lw6gfx-is-key-del");
 
-      c_keysym = SCM_INUM (keysym);
+      c_keysym = scm_to_int (keysym);
 
       ret =
 	lw6gfx_is_key_del (lw6_global.gfx_backend,
@@ -818,9 +820,9 @@ scm_lw6gfx_is_key_backspace (SCM keysym)
   if (lw6_global.gfx_backend != NULL)
     {
       int c_keysym;
-      SCM_ASSERT (SCM_INUMP (keysym), keysym, SCM_ARG1,
+      SCM_ASSERT (scm_is_integer (keysym), keysym, SCM_ARG1,
 		  "c-lw6gfx-is-key-backspace");
-      c_keysym = SCM_INUM (keysym);
+      c_keysym = scm_to_int (keysym);
       ret =
 	lw6gfx_is_key_backspace (lw6_global.gfx_backend,
 				 c_keysym) ? SCM_BOOL_T : SCM_BOOL_F;
@@ -840,9 +842,9 @@ scm_lw6gfx_is_key_help (SCM keysym)
   if (lw6_global.gfx_backend != NULL)
     {
       int c_keysym;
-      SCM_ASSERT (SCM_INUMP (keysym), keysym, SCM_ARG1,
+      SCM_ASSERT (scm_is_integer (keysym), keysym, SCM_ARG1,
 		  "c-lw6gfx-is-key-help");
-      c_keysym = SCM_INUM (keysym);
+      c_keysym = scm_to_int (keysym);
       ret =
 	lw6gfx_is_key_help (lw6_global.gfx_backend,
 			    c_keysym) ? SCM_BOOL_T : SCM_BOOL_F;
@@ -862,9 +864,9 @@ scm_lw6gfx_is_key_quit (SCM keysym)
   if (lw6_global.gfx_backend != NULL)
     {
       int c_keysym;
-      SCM_ASSERT (SCM_INUMP (keysym), keysym, SCM_ARG1,
+      SCM_ASSERT (scm_is_integer (keysym), keysym, SCM_ARG1,
 		  "c-lw6gfx-is-key-quit");
-      c_keysym = SCM_INUM (keysym);
+      c_keysym = scm_to_int (keysym);
       ret =
 	lw6gfx_is_key_quit (lw6_global.gfx_backend,
 			    c_keysym) ? SCM_BOOL_T : SCM_BOOL_F;
@@ -912,9 +914,9 @@ scm_lw6gfx_get_key_state (SCM keysym)
   if (lw6_global.gfx_backend != NULL)
     {
       int c_keysym;
-      SCM_ASSERT (SCM_INUMP (keysym), keysym, SCM_ARG1,
+      SCM_ASSERT (scm_is_integer (keysym), keysym, SCM_ARG1,
 		  "c-lw6gfx-get-key-state");
-      c_keysym = SCM_INUM (keysym);
+      c_keysym = scm_to_int (keysym);
       ret =
 	lw6gfx_get_key_state (lw6_global.gfx_backend,
 			      c_keysym) ? SCM_BOOL_T : SCM_BOOL_F;
@@ -960,9 +962,9 @@ scm_lw6gfx_poll_mouse_button (SCM button)
   if (lw6_global.gfx_backend != NULL)
     {
       int c_button;
-      SCM_ASSERT (SCM_INUMP (button), button, SCM_ARG1,
+      SCM_ASSERT (scm_is_integer (button), button, SCM_ARG1,
 		  "c-lw6gfx-poll-mouse-button");
-      c_button = SCM_INUM (button);
+      c_button = scm_to_int (button);
       ret =
 	lw6gfx_poll_mouse_button (lw6_global.gfx_backend,
 				  c_button) ? SCM_BOOL_T : SCM_BOOL_F;
@@ -1023,10 +1025,12 @@ scm_lw6gfx_display_hud (SCM game_state, SCM step, SCM skin)
       SCM_ASSERT (SCM_SMOB_PREDICATE
 		  (lw6_global.smob_types.game_state,
 		   game_state), game_state, SCM_ARG1, "c-lw6gfx-display-hud");
-      SCM_ASSERT (SCM_INUMP (step), step, SCM_ARG2, "c-lw6gfx-display-hud");
-      SCM_ASSERT (SCM_STRINGP (skin), skin, SCM_ARG3, "c-lw6gfx-display-hud");
+      SCM_ASSERT (scm_is_integer (step), step, SCM_ARG2,
+		  "c-lw6gfx-display-hud");
+      SCM_ASSERT (scm_is_string (skin), skin, SCM_ARG3,
+		  "c-lw6gfx-display-hud");
 
-      c_step = SCM_INUM (step);
+      c_step = scm_to_int (step);
       c_skin = to_0str (skin);
       if (c_skin)
 	{
@@ -1049,12 +1053,12 @@ scm_lw6gfx_display_hud_preview (SCM step, SCM skin)
       int c_step;
       char *c_skin;
 
-      SCM_ASSERT (SCM_INUMP (step), step, SCM_ARG1,
+      SCM_ASSERT (scm_is_integer (step), step, SCM_ARG1,
 		  "c-lw6gfx-display-hud-preview");
-      SCM_ASSERT (SCM_STRINGP (skin), skin, SCM_ARG2,
+      SCM_ASSERT (scm_is_string (skin), skin, SCM_ARG2,
 		  "c-lw6gfx-display-hud-preview");
 
-      c_step = SCM_INUM (step);
+      c_step = scm_to_int (step);
       c_skin = to_0str (skin);
       if (c_skin)
 	{
@@ -1078,16 +1082,18 @@ scm_lw6gfx_display_sysinfo (SCM fps, SCM rps, SCM bytes_in, SCM bytes_out)
       int c_rps;
       int c_bytes_in;
       int c_bytes_out;
-      SCM_ASSERT (SCM_INUMP (fps), fps, SCM_ARG1, "c-lw6sys-display-sysinfo");
-      SCM_ASSERT (SCM_INUMP (rps), rps, SCM_ARG2, "c-lw6sys-display-sysinfo");
-      SCM_ASSERT (SCM_INUMP (bytes_in), bytes_in,
-		  SCM_ARG3, "c-lw6sys-display-sysinfo");
-      SCM_ASSERT (SCM_INUMP (bytes_out), bytes_out,
-		  SCM_ARG4, "c-lw6sys-display-sysinfo");
-      c_fps = SCM_INUM (fps);
-      c_rps = SCM_INUM (rps);
-      c_bytes_in = SCM_INUM (bytes_in);
-      c_bytes_out = SCM_INUM (bytes_out);
+      SCM_ASSERT (scm_is_integer (fps), fps, SCM_ARG1,
+		  "c-lw6sys-display-sysinfo");
+      SCM_ASSERT (scm_is_integer (rps), rps, SCM_ARG2,
+		  "c-lw6sys-display-sysinfo");
+      SCM_ASSERT (scm_is_integer (bytes_in), bytes_in, SCM_ARG3,
+		  "c-lw6sys-display-sysinfo");
+      SCM_ASSERT (scm_is_integer (bytes_out), bytes_out, SCM_ARG4,
+		  "c-lw6sys-display-sysinfo");
+      c_fps = scm_to_int (fps);
+      c_rps = scm_to_int (rps);
+      c_bytes_in = scm_to_int (bytes_in);
+      c_bytes_out = scm_to_int (bytes_out);
       lw6gfx_display_sysinfo (lw6_global.gfx_backend,
 			      c_fps, c_rps, c_bytes_in, c_bytes_out);
     }
@@ -1103,7 +1109,7 @@ scm_lw6gfx_display_log (SCM log)
       int log_size;
       char **c_log;
       SCM_ASSERT (SCM_CONSP (log), log, SCM_ARG1, "c-lw6sys-display-log");
-      log_size = SCM_INUM (scm_length (log));
+      log_size = scm_to_int (scm_length (log));
       c_log = LW6SYS_MALLOC ((log_size + 1) * sizeof (char *));
       if (c_log)
 	{
@@ -1170,7 +1176,7 @@ scm_lw6gfx_display_map_preview (SCM map, SCM skin)
       SCM_ASSERT (SCM_SMOB_PREDICATE
 		  (lw6_global.smob_types.map, map), map,
 		  SCM_ARG1, "c-lw6gfx-display-map-preview");
-      SCM_ASSERT (SCM_STRINGP (skin), skin, SCM_ARG2,
+      SCM_ASSERT (scm_is_string (skin), skin, SCM_ARG2,
 		  "c-lw6gfx-display-map-preview");
       c_skin = to_0str (skin);
       if (c_skin)
@@ -1198,7 +1204,7 @@ scm_lw6gfx_display_map_zones (SCM map, SCM game_struct, SCM skin)
 		  (lw6_global.smob_types.game_struct,
 		   game_struct), game_struct, SCM_ARG2,
 		  "c-lw6gfx-display-map-zones");
-      SCM_ASSERT (SCM_STRINGP (skin), skin, SCM_ARG3,
+      SCM_ASSERT (scm_is_string (skin), skin, SCM_ARG3,
 		  "c-lw6gfx-display-map-zones");
       c_skin = to_0str (skin);
       if (c_skin)
@@ -1232,9 +1238,9 @@ scm_lw6gfx_display_map_gradient (SCM map, SCM game_state, SCM team_id,
 		  (lw6_global.smob_types.game_state,
 		   game_state), game_state, SCM_ARG2,
 		  "c-lw6gfx-display-map-gradient");
-      SCM_ASSERT (SCM_INUMP (team_id), team_id, SCM_ARG3,
+      SCM_ASSERT (scm_is_integer (team_id), team_id, SCM_ARG3,
 		  "c-lw6gfx-display-map-gradient");
-      SCM_ASSERT (SCM_STRINGP (skin), skin, SCM_ARG4,
+      SCM_ASSERT (scm_is_string (skin), skin, SCM_ARG4,
 		  "c-lw6gfx-display-map-gradient");
       c_skin = to_0str (skin);
       if (c_skin)
@@ -1245,7 +1251,7 @@ scm_lw6gfx_display_map_gradient (SCM map, SCM game_state, SCM team_id,
 
 	  c_map = lw6_scm_to_map (map);
 	  c_game_state = lw6_scm_to_game_state (game_state);
-	  c_team_id = SCM_INUM (team_id);
+	  c_team_id = scm_to_int (team_id);
 
 	  lw6gfx_display_map_gradient (lw6_global.
 				       gfx_backend,
@@ -1275,7 +1281,7 @@ scm_lw6gfx_display_game (SCM map, SCM game_state, SCM game_look, SCM skin)
       SCM_ASSERT (SCM_SMOB_PREDICATE
 		  (lw6_global.smob_types.game_look,
 		   game_look), game_look, SCM_ARG3, "c-lw6gfx-display-game");
-      SCM_ASSERT (SCM_STRINGP (skin), skin, SCM_ARG4,
+      SCM_ASSERT (scm_is_string (skin), skin, SCM_ARG4,
 		  "c-lw6gfx-display-game");
       c_skin = to_0str (skin);
       if (c_skin)
@@ -1312,11 +1318,11 @@ scm_lw6gfx_pick_map_coord (SCM map, SCM game_state, SCM screen_x,
 		  (lw6_global.smob_types.game_state,
 		   game_state), game_state, SCM_ARG2,
 		  "c-lw6gfx-pick-map-coord");
-      SCM_ASSERT (SCM_INUMP (screen_x), screen_x, SCM_ARG3,
+      SCM_ASSERT (scm_is_integer (screen_x), screen_x, SCM_ARG3,
 		  "c-lw6gfx-pick-map-coord");
-      SCM_ASSERT (SCM_INUMP (screen_y), screen_y, SCM_ARG4,
+      SCM_ASSERT (scm_is_integer (screen_y), screen_y, SCM_ARG4,
 		  "c-lw6gfx-pick-map-coord");
-      SCM_ASSERT (SCM_STRINGP (skin), skin, SCM_ARG5,
+      SCM_ASSERT (scm_is_string (skin), skin, SCM_ARG5,
 		  "c-lw6gfx-pick-map-coord");
       c_skin = to_0str (skin);
       if (c_skin)
@@ -1330,8 +1336,8 @@ scm_lw6gfx_pick_map_coord (SCM map, SCM game_state, SCM screen_x,
 
 	  c_map = lw6_scm_to_map (map);
 	  c_game_state = lw6_scm_to_game_state (game_state);
-	  c_screen_x = SCM_INUM (screen_x);
-	  c_screen_y = SCM_INUM (screen_y);
+	  c_screen_x = scm_to_int (screen_x);
+	  c_screen_y = scm_to_int (screen_y);
 
 	  lw6gfx_pick_map_coord (lw6_global.gfx_backend, &c_map_x, &c_map_y,
 				 c_map, c_game_state, c_screen_x, c_screen_y,
@@ -1363,7 +1369,7 @@ scm_lw6gfx_display_menu (SCM menu, SCM skin)
       SCM_ASSERT (SCM_CONSP (menu)
 		  || menu == SCM_EOL, menu, SCM_ARG1,
 		  "c-lw6gfx-display-menu");
-      SCM_ASSERT (SCM_STRINGP (skin), skin, SCM_ARG2,
+      SCM_ASSERT (scm_is_string (skin), skin, SCM_ARG2,
 		  "c-lw6gfx-display-menu");
       c_skin = to_0str (skin);
       if (c_skin)
@@ -1376,12 +1382,13 @@ scm_lw6gfx_display_menu (SCM menu, SCM skin)
 
 	  c_id = to_0str (scm_assoc_ref (menu, scm_makfrom0str ("id")));
 	  c_label = to_0str (scm_assoc_ref (menu, scm_makfrom0str ("label")));
-	  c_type = SCM_INUM (scm_assoc_ref (menu, scm_makfrom0str ("type")));
+	  c_type =
+	    scm_to_int (scm_assoc_ref (menu, scm_makfrom0str ("type")));
 	  c_selected_item =
-	    SCM_INUM (scm_assoc_ref
-		      (menu, scm_makfrom0str ("selected-item")));
+	    scm_to_int (scm_assoc_ref
+			(menu, scm_makfrom0str ("selected-item")));
 	  items = scm_assoc_ref (menu, scm_makfrom0str ("items"));
-	  c_nb_items = SCM_INUM (scm_length (items));
+	  c_nb_items = scm_to_int (scm_length (items));
 
 	  c_menu =
 	    lw6gfx_menu_new (c_id, c_label, c_type, c_selected_item,
@@ -1405,16 +1412,17 @@ scm_lw6gfx_display_menu (SCM menu, SCM skin)
 		  c_label =
 		    to_0str (scm_assoc_ref (item, scm_makfrom0str ("label")));
 		  c_type =
-		    SCM_INUM (scm_assoc_ref (item, scm_makfrom0str ("type")));
+		    scm_to_int (scm_assoc_ref
+				(item, scm_makfrom0str ("type")));
 		  c_enabled =
-		    SCM_INUM (scm_assoc_ref
-			      (item, scm_makfrom0str ("enabled")));
+		    scm_to_int (scm_assoc_ref
+				(item, scm_makfrom0str ("enabled")));
 		  c_value =
-		    SCM_INUM (scm_assoc_ref
-			      (item, scm_makfrom0str ("value")));
+		    scm_to_int (scm_assoc_ref
+				(item, scm_makfrom0str ("value")));
 		  c_selected_char =
-		    SCM_INUM (scm_assoc_ref
-			      (item, scm_makfrom0str ("selected-char")));
+		    scm_to_int (scm_assoc_ref
+				(item, scm_makfrom0str ("selected-char")));
 		  c_menuitem =
 		    lw6gfx_menuitem_new (c_label, c_type, c_enabled, c_value,
 					 c_selected_char);
@@ -1449,14 +1457,14 @@ scm_lw6gfx_pick_menuitem (SCM menu, SCM screen_x, SCM screen_y, SCM skin)
       SCM items;
       SCM_ASSERT (SCM_CONSP (menu), menu, SCM_ARG1,
 		  "c-lw6gfx-display-menuitem");
-      SCM_ASSERT (SCM_INUMP (screen_x), screen_x, SCM_ARG2,
+      SCM_ASSERT (scm_is_integer (screen_x), screen_x, SCM_ARG2,
 		  "c-lw6gfx-pick-menuitem");
-      SCM_ASSERT (SCM_INUMP (screen_y), screen_y, SCM_ARG3,
+      SCM_ASSERT (scm_is_integer (screen_y), screen_y, SCM_ARG3,
 		  "c-lw6gfx-pick-menuitem");
-      SCM_ASSERT (SCM_STRINGP (skin), skin, SCM_ARG4,
+      SCM_ASSERT (scm_is_string (skin), skin, SCM_ARG4,
 		  "c-lw6gfx-pick-menuitem");
-      c_screen_x = SCM_INUM (screen_x);
-      c_screen_y = SCM_INUM (screen_y);
+      c_screen_x = scm_to_int (screen_x);
+      c_screen_y = scm_to_int (screen_y);
       c_skin = to_0str (skin);
       if (c_skin)
 	{
@@ -1468,12 +1476,13 @@ scm_lw6gfx_pick_menuitem (SCM menu, SCM screen_x, SCM screen_y, SCM skin)
 
 	  c_id = to_0str (scm_assoc_ref (menu, scm_makfrom0str ("id")));
 	  c_label = to_0str (scm_assoc_ref (menu, scm_makfrom0str ("label")));
-	  c_type = SCM_INUM (scm_assoc_ref (menu, scm_makfrom0str ("type")));
+	  c_type =
+	    scm_to_int (scm_assoc_ref (menu, scm_makfrom0str ("type")));
 	  c_selected_item =
-	    SCM_INUM (scm_assoc_ref
-		      (menu, scm_makfrom0str ("selected-item")));
+	    scm_to_int (scm_assoc_ref
+			(menu, scm_makfrom0str ("selected-item")));
 	  items = scm_assoc_ref (menu, scm_makfrom0str ("items"));
-	  c_nb_items = SCM_INUM (scm_length (items));
+	  c_nb_items = scm_to_int (scm_length (items));
 
 	  c_menu =
 	    lw6gfx_menu_new (c_id, c_label, c_type, c_selected_item,
@@ -1497,16 +1506,17 @@ scm_lw6gfx_pick_menuitem (SCM menu, SCM screen_x, SCM screen_y, SCM skin)
 		  c_label =
 		    to_0str (scm_assoc_ref (item, scm_makfrom0str ("label")));
 		  c_type =
-		    SCM_INUM (scm_assoc_ref (item, scm_makfrom0str ("type")));
+		    scm_to_int (scm_assoc_ref
+				(item, scm_makfrom0str ("type")));
 		  c_enabled =
-		    SCM_INUM (scm_assoc_ref
-			      (item, scm_makfrom0str ("enabled")));
+		    scm_to_int (scm_assoc_ref
+				(item, scm_makfrom0str ("enabled")));
 		  c_value =
-		    SCM_INUM (scm_assoc_ref
-			      (item, scm_makfrom0str ("value")));
+		    scm_to_int (scm_assoc_ref
+				(item, scm_makfrom0str ("value")));
 		  c_selected_char =
-		    SCM_INUM (scm_assoc_ref
-			      (item, scm_makfrom0str ("selected-char")));
+		    scm_to_int (scm_assoc_ref
+				(item, scm_makfrom0str ("selected-char")));
 		  c_menuitem =
 		    lw6gfx_menuitem_new (c_label, c_type, c_enabled, c_value,
 					 c_selected_char);
@@ -1564,15 +1574,15 @@ scm_lw6gfx_init (SCM width, SCM height, SCM fullscreen, SCM ticks)
       int c_height;
       int c_fullscreen;
       int c_ticks;
-      SCM_ASSERT (SCM_INUMP (width), width, SCM_ARG1, "c-lw6gfx-init");
-      SCM_ASSERT (SCM_INUMP (height), height, SCM_ARG2, "c-lw6gfx-init");
+      SCM_ASSERT (scm_is_integer (width), width, SCM_ARG1, "c-lw6gfx-init");
+      SCM_ASSERT (scm_is_integer (height), height, SCM_ARG2, "c-lw6gfx-init");
       SCM_ASSERT (SCM_BOOLP (fullscreen), fullscreen, SCM_ARG3,
 		  "c-lw6gfx-init");
-      SCM_ASSERT (SCM_INUMP (ticks), ticks, SCM_ARG4, "c-lw6gfx-init");
-      c_width = SCM_INUM (width);
-      c_height = SCM_INUM (height);
+      SCM_ASSERT (scm_is_integer (ticks), ticks, SCM_ARG4, "c-lw6gfx-init");
+      c_width = scm_to_int (width);
+      c_height = scm_to_int (height);
       c_fullscreen = SCM_NFALSEP (fullscreen);
-      c_ticks = SCM_INUM (ticks);
+      c_ticks = scm_to_int (ticks);
       if (lw6gfx_init (lw6_global.gfx_backend, c_width,
 		       c_height, c_fullscreen, lw6_resize_callback, c_ticks))
 	{
@@ -1593,12 +1603,12 @@ scm_lw6gfx_set_video_mode (SCM width, SCM height, SCM fullscreen)
       int c_width;
       int c_height;
       int c_fullscreen;
-      SCM_ASSERT (SCM_INUMP (width),
+      SCM_ASSERT (scm_is_integer (width),
 		  width, SCM_ARG1, "c-lw6gfx-set-video-mode");
-      SCM_ASSERT (SCM_INUMP (height), height, SCM_ARG2,
+      SCM_ASSERT (scm_is_integer (height), height, SCM_ARG2,
 		  "c-lw6gfx-set-video-mode");
-      c_width = SCM_INUM (width);
-      c_height = SCM_INUM (height);
+      c_width = scm_to_int (width);
+      c_height = scm_to_int (height);
       c_fullscreen = SCM_NFALSEP (fullscreen);
       ret =
 	lw6gfx_set_video_mode (lw6_global.gfx_backend,
@@ -1635,8 +1645,8 @@ scm_lw6gfx_delay (SCM ms)
   int c_ms;
   if (lw6_global.gfx_backend != NULL)
     {
-      SCM_ASSERT (SCM_INUMP (ms), ms, SCM_ARG1, "c-lw6gfx-delay");
-      c_ms = SCM_INUM (ms);
+      SCM_ASSERT (scm_is_integer (ms), ms, SCM_ARG1, "c-lw6gfx-delay");
+      c_ms = scm_to_int (ms);
       lw6gfx_delay (lw6_global.gfx_backend, c_ms);
     }
 
@@ -1711,7 +1721,7 @@ scm_lw6map_get_maps (SCM dir)
   LW6MAP_ENTRY *c_entry;
   char *c_dir;
   SCM ret;
-  SCM_ASSERT (SCM_STRINGP (dir), dir, SCM_ARG1, "c-lw6map-get-system-maps");
+  SCM_ASSERT (scm_is_string (dir), dir, SCM_ARG1, "c-lw6map-get-system-maps");
   ret = SCM_LIST0;
   c_dir = to_0str (dir);
   if (c_dir)
@@ -1759,7 +1769,7 @@ scm_lw6map_read (SCM dirname)
   char *c_dirname;
   SCM ret;
 
-  SCM_ASSERT (SCM_STRINGP (dirname), dirname, SCM_ARG1, "c-lw6map-read");
+  SCM_ASSERT (scm_is_string (dirname), dirname, SCM_ARG1, "c-lw6map-read");
 
   c_dirname = to_0str (dirname);
   if (c_dirname)
@@ -2023,10 +2033,11 @@ scm_lw6ker_get_cursors (SCM game_state, SCM team_id)
   SCM_ASSERT (SCM_SMOB_PREDICATE
 	      (lw6_global.smob_types.game_state,
 	       game_state), game_state, SCM_ARG1, "c-lw6ker-get-cursors");
-  SCM_ASSERT (SCM_INUMP (team_id), team_id, SCM_ARG2, "c-lw6ker-get-cursors");
+  SCM_ASSERT (scm_is_integer (team_id), team_id, SCM_ARG2,
+	      "c-lw6ker-get-cursors");
 
   c_game_state = lw6_scm_to_game_state (game_state);
-  c_team_id = SCM_INUM (team_id);
+  c_team_id = scm_to_int (team_id);
   if (c_game_state)
     {
       int i;
@@ -2063,13 +2074,14 @@ scm_lw6ker_set_cursors (SCM game_state, SCM team_id, SCM cursor_array)
   SCM_ASSERT (SCM_SMOB_PREDICATE
 	      (lw6_global.smob_types.game_state,
 	       game_state), game_state, SCM_ARG1, "c-lw6ker-set-cursors");
-  SCM_ASSERT (SCM_INUMP (team_id), team_id, SCM_ARG2, "c-lw6ker-set-cursors");
+  SCM_ASSERT (scm_is_integer (team_id), team_id, SCM_ARG2,
+	      "c-lw6ker-set-cursors");
   SCM_ASSERT (SCM_CONSP (cursor_array)
 	      || cursor_array == SCM_EOL, cursor_array, SCM_ARG3,
 	      "c-lw6ker-set-cursors");
 
   c_game_state = lw6_scm_to_game_state (game_state);
-  c_team_id = SCM_INUM (team_id);
+  c_team_id = scm_to_int (team_id);
   if (c_game_state)
     {
       int i = 0;
@@ -2078,20 +2090,22 @@ scm_lw6ker_set_cursors (SCM game_state, SCM team_id, SCM cursor_array)
 	&(c_game_state->map.teams[c_team_id].cursor_array);
       SCM cursor;
 
-      n = SCM_INUM (scm_length (cursor_array));
+      n = scm_to_int (scm_length (cursor_array));
       for (i = 0; i < n; ++i)
 	{
 	  cursor = scm_list_ref (cursor_array, scm_int2num (i));
 	  lw6ker_cursor_array_set (c_cursor_array,
 				   i,
-				   SCM_INUM (scm_assoc_ref
-					     (cursor, scm_makfrom0str ("x"))),
-				   SCM_INUM (scm_assoc_ref
-					     (cursor, scm_makfrom0str ("y"))),
-				   SCM_INUM (scm_assoc_ref
-					     (cursor,
-					      scm_makfrom0str
-					      ("pot-offset"))),
+				   scm_to_int (scm_assoc_ref
+					       (cursor,
+						scm_makfrom0str ("x"))),
+				   scm_to_int (scm_assoc_ref
+					       (cursor,
+						scm_makfrom0str ("y"))),
+				   scm_to_int (scm_assoc_ref
+					       (cursor,
+						scm_makfrom0str
+						("pot-offset"))),
 				   &(c_game_state->game_struct->map),
 				   c_game_state->game_struct->options.
 				   max_cursor_pot_offset);
@@ -2112,10 +2126,11 @@ scm_lw6ker_enable_bot (SCM game_state, SCM team_id)
   SCM_ASSERT (SCM_SMOB_PREDICATE
 	      (lw6_global.smob_types.game_state,
 	       game_state), game_state, SCM_ARG1, "c-lw6ker-enable-bot");
-  SCM_ASSERT (SCM_INUMP (team_id), team_id, SCM_ARG2, "c-lw6ker-enable-bot");
+  SCM_ASSERT (scm_is_integer (team_id), team_id, SCM_ARG2,
+	      "c-lw6ker-enable-bot");
 
   c_game_state = lw6_scm_to_game_state (game_state);
-  c_team_id = SCM_INUM (team_id);
+  c_team_id = scm_to_int (team_id);
   if (c_game_state)
     {
       ret =
@@ -2136,10 +2151,11 @@ scm_lw6ker_disable_bot (SCM game_state, SCM team_id)
   SCM_ASSERT (SCM_SMOB_PREDICATE
 	      (lw6_global.smob_types.game_state,
 	       game_state), game_state, SCM_ARG1, "c-lw6ker-disable-bot");
-  SCM_ASSERT (SCM_INUMP (team_id), team_id, SCM_ARG2, "c-lw6ker-disable-bot");
+  SCM_ASSERT (scm_is_integer (team_id), team_id, SCM_ARG2,
+	      "c-lw6ker-disable-bot");
 
   c_game_state = lw6_scm_to_game_state (game_state);
-  c_team_id = SCM_INUM (team_id);
+  c_team_id = scm_to_int (team_id);
   if (c_game_state)
     {
       ret =
@@ -2244,13 +2260,13 @@ scm_lw6ker_add_team (SCM game_state, SCM team_id, SCM nb_cursors)
       SCM_ASSERT (SCM_SMOB_PREDICATE
 		  (lw6_global.smob_types.game_state,
 		   game_state), game_state, SCM_ARG1, "c-lw6ker-add-team");
-      SCM_ASSERT (SCM_INUMP (team_id), team_id, SCM_ARG2,
+      SCM_ASSERT (scm_is_integer (team_id), team_id, SCM_ARG2,
 		  "c-lw6ker-add-team");
-      SCM_ASSERT (SCM_INUMP (nb_cursors), nb_cursors,
+      SCM_ASSERT (scm_is_integer (nb_cursors), nb_cursors,
 		  SCM_ARG3, "c-lw6ker-add-team");
       c_game_state = lw6_scm_to_game_state (game_state);
-      c_team_id = SCM_INUM (team_id);
-      c_nb_cursors = SCM_INUM (nb_cursors);
+      c_team_id = scm_to_int (team_id);
+      c_nb_cursors = scm_to_int (nb_cursors);
       if (c_game_state)
 	{
 	  ret =
@@ -2283,10 +2299,10 @@ scm_lw6ker_remove_team (SCM game_state, SCM team_id, SCM nb_cursors)
       SCM_ASSERT (SCM_SMOB_PREDICATE
 		  (lw6_global.smob_types.game_state,
 		   game_state), game_state, SCM_ARG1, "c-lw6ker-remove-team");
-      SCM_ASSERT (SCM_INUMP (team_id), team_id, SCM_ARG2,
+      SCM_ASSERT (scm_is_integer (team_id), team_id, SCM_ARG2,
 		  "c-lw6ker-remove-team");
       c_game_state = lw6_scm_to_game_state (game_state);
-      c_team_id = SCM_INUM (team_id);
+      c_team_id = scm_to_int (team_id);
       if (c_game_state)
 	{
 	  ret =
@@ -2364,7 +2380,7 @@ scm_lw6snd_create_backend (SCM backend_name)
     {
       char *c_backend_name;
 
-      SCM_ASSERT (SCM_STRINGP (backend_name),
+      SCM_ASSERT (scm_is_string (backend_name),
 		  backend_name, SCM_ARG1, "c-lw6snd-create-backend");
 
       c_backend_name = to_0str (backend_name);
@@ -2451,14 +2467,14 @@ scm_lw6snd_play_sound (SCM sound_id)
 {
   SCM ret = SCM_BOOL_F;
 
-  SCM_ASSERT (SCM_INUMP (sound_id), sound_id, SCM_ARG1,
+  SCM_ASSERT (scm_is_integer (sound_id), sound_id, SCM_ARG1,
 	      "c-lw6snd-play-sound");
 
   if (lw6_global.snd_backend != NULL && lw6_global.snd_initialized)
     {
       int c_sound_id;
 
-      c_sound_id = SCM_INUM (sound_id);
+      c_sound_id = scm_to_int (sound_id);
 
       ret =
 	scm_int2num (lw6snd_play_sound (lw6_global.snd_backend, c_sound_id));
@@ -2489,7 +2505,7 @@ scm_lw6snd_play_music (SCM music_name)
 {
   SCM ret = SCM_BOOL_F;
 
-  SCM_ASSERT (SCM_STRINGP (music_name), music_name, SCM_ARG1,
+  SCM_ASSERT (scm_is_string (music_name), music_name, SCM_ARG1,
 	      "c-lw6snd-play-music");
 
   if (lw6_global.snd_backend != NULL && lw6_global.snd_initialized)
@@ -2559,6 +2575,122 @@ scm_lw6con_poll ()
   return SCM_UNDEFINED;
 }
 
+
+/*
+ * In liquidwar6net
+ */
+
+/*
+ * In setup.c
+ */
+static SCM
+scm_lw6net_init ()
+{
+  SCM ret = SCM_BOOL_F;
+
+  lw6_global.net_context = lw6net_init ();
+  if (lw6_global.net_context)
+    {
+      lw6_global.net_initialized = 1;
+      ret = SCM_BOOL_F;
+    }
+
+  return ret;
+}
+
+static SCM
+scm_lw6net_quit ()
+{
+  if (lw6_global.net_initialized && (lw6_global.net_context != NULL))
+    {
+      lw6net_quit (lw6_global.net_context);
+    }
+  lw6_global.net_context = NULL;
+  lw6_global.net_initialized = 0;
+
+  return SCM_UNDEFINED;
+}
+
+static SCM
+scm_lw6net_server_start (SCM ip, SCM port)
+{
+  SCM ret = SCM_BOOL_F;
+  char *c_ip;
+  int c_port;
+
+  SCM_ASSERT (scm_is_string (ip), ip, SCM_ARG1, "c-lw6net-server-start");
+  SCM_ASSERT (scm_is_integer (port), port, SCM_ARG2, "c-lw6net-server-start");
+
+  if (lw6_global.net_context)
+    {
+      c_ip = to_0str (ip);
+      if (c_ip)
+	{
+	  c_port = scm_to_int (port);
+	  ret =
+	    lw6net_server_start (lw6_global.net_context, c_ip,
+				 c_port) ? SCM_BOOL_T : SCM_BOOL_F;
+	  LW6SYS_FREE (c_ip);
+	}
+    }
+
+  return ret;
+}
+
+static SCM
+scm_lw6net_server_poll_idle ()
+{
+  SCM ret = SCM_BOOL_F;
+
+  if (lw6_global.net_context)
+    {
+      ret =
+	lw6net_server_poll (lw6_global.net_context,
+			    NULL, NULL) ? SCM_BOOL_T : SCM_BOOL_F;
+    }
+
+  return ret;
+}
+
+static SCM
+scm_lw6net_server_poll_playing (SCM map, SCM game_state)
+{
+  SCM ret = SCM_BOOL_F;
+
+  if (lw6_global.net_context)
+    {
+      LW6MAP_MAP *c_map;
+      LW6KER_GAME_STATE *c_game_state;
+
+      SCM_ASSERT (SCM_SMOB_PREDICATE
+		  (lw6_global.smob_types.map,
+		   map), map, SCM_ARG1, "c-lw6net-server-poll");
+      SCM_ASSERT (SCM_SMOB_PREDICATE
+		  (lw6_global.smob_types.game_state,
+		   game_state), game_state, SCM_ARG2, "c-lw6net-server-poll");
+
+      c_map = lw6_scm_to_map (map);
+      c_game_state = lw6_scm_to_game_state (game_state);
+
+      ret =
+	lw6net_server_poll (lw6_global.net_context,
+			    c_map, c_game_state) ? SCM_BOOL_T : SCM_BOOL_F;
+    }
+
+  return ret;
+}
+
+static SCM
+scm_lw6net_server_stop ()
+{
+  if (lw6_global.net_context)
+    {
+      lw6net_server_stop (lw6_global.net_context);
+    }
+
+  return SCM_UNDEFINED;
+}
+
 /*
  * Register all the functions, make them callable from Guile.
  */
@@ -2850,6 +2982,23 @@ lw6_register_funcs ()
   scm_c_define_gsubr ("c-lw6con-quit", 0, 0, 0, (SCM (*)())scm_lw6con_quit);
   scm_c_define_gsubr ("c-lw6con-poll", 0, 0, 0, (SCM (*)())scm_lw6con_poll);
 
+  /*
+   * In liquidwar6net
+   */
+  /*
+   * In setup.c
+   */
+  scm_c_define_gsubr ("c-lw6net-init", 0, 0, 0, (SCM (*)())scm_lw6net_init);
+  scm_c_define_gsubr ("c-lw6net-quit", 0, 0, 0, (SCM (*)())scm_lw6net_quit);
+  scm_c_define_gsubr ("c-lw6net-server-start", 2, 0, 0,
+		      (SCM (*)())scm_lw6net_server_start);
+  scm_c_define_gsubr ("c-lw6net-server-poll-idle", 0, 0, 0,
+		      (SCM (*)())scm_lw6net_server_poll_idle);
+  scm_c_define_gsubr ("c-lw6net-server-poll-playing", 2, 0, 0,
+		      (SCM (*)())scm_lw6net_server_poll_playing);
+  scm_c_define_gsubr ("c-lw6net-server-stop", 0, 0, 0,
+		      (SCM (*)())scm_lw6net_server_stop);
+
   return ret;
 }
 
