@@ -1,11 +1,11 @@
 /*
 Liquid War 6 is a unique multiplayer wargame.
-Copyright (C)  2005, 2006  Christian Mauduit <ufoot@ufoot.org>
+Copyright (C)  2005, 2006, 2007  Christian Mauduit <ufoot@ufoot.org>
 
-This program is free software; you can redistribute it and/or
-modify it under the terms of the GNU General Public License
-as published by the Free Software Foundation; either version 2
-of the License, or (at your option) any later version.
+This program is free software; you can redistribute it and/or modify
+it under the terms of the GNU General Public License as published by
+the Free Software Foundation, either version 3 of the License, or
+(at your option) any later version.
 
 This program is distributed in the hope that it will be useful,
 but WITHOUT ANY WARRANTY; without even the implied warranty of
@@ -13,8 +13,8 @@ MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 GNU General Public License for more details.
 
 You should have received a copy of the GNU General Public License
-along with this program; if not, write to the Free Software
-Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
+along with this program.  If not, see <http://www.gnu.org/licenses/>.
+
 
 Liquid War 6 homepage : http://www.gnu.org/software/liquidwar6/
 Contact author        : ufoot@ufoot.org
@@ -490,6 +490,28 @@ lw6ker_map_state_remove_team_fighters (LW6KER_MAP_STATE * map_state,
   return ret;
 }
 
+LW6KER_FIGHTER *
+lw6ker_map_state_get_fighter_safe (LW6KER_MAP_STATE * map_state,
+				   LW6SYS_INT32 layer, LW6SYS_INT32 x,
+				   LW6SYS_INT32 y)
+{
+  LW6KER_FIGHTER *ret = NULL;
+  int fighter_id;
+
+  if (layer >= 0 && layer < map_state->nb_layers && x >= 0
+      && x <= map_state->shape.w && y >= 0 && y < map_state->shape.h)
+    {
+      fighter_id =
+	map_state->layers[layer].slots[map_state->shape.w * y + x].fighter_id;
+      if (fighter_id >= 0)
+	{
+	  ret = &(map_state->armies.fighters[fighter_id]);
+	}
+    }
+
+  return ret;
+};
+
 void
 lw6ker_map_state_print_debug (LW6KER_MAP_STATE * map_state)
 {
