@@ -1,11 +1,11 @@
 /*
   Liquid War 6 is a unique multiplayer wargame.
-  Copyright (C)  2005, 2006  Christian Mauduit <ufoot@ufoot.org>
+  Copyright (C)  2005, 2006, 2007  Christian Mauduit <ufoot@ufoot.org>
 
-  This program is free software; you can redistribute it and/or
-  modify it under the terms of the GNU General Public License
-  as published by the Free Software Foundation; either version 2
-  of the License, or (at your option) any later version.
+  This program is free software; you can redistribute it and/or modify
+  it under the terms of the GNU General Public License as published by
+  the Free Software Foundation, either version 3 of the License, or
+  (at your option) any later version.
 
   This program is distributed in the hope that it will be useful,
   but WITHOUT ANY WARRANTY; without even the implied warranty of
@@ -13,8 +13,8 @@
   GNU General Public License for more details.
 
   You should have received a copy of the GNU General Public License
-  along with this program; if not, write to the Free Software
-  Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
+  along with this program.  If not, see <http://www.gnu.org/licenses/>.
+  
 
   Liquid War 6 homepage : http://www.gnu.org/software/liquidwar6/
   Contact author        : ufoot@ufoot.org
@@ -396,14 +396,19 @@ lw6ker_map_state_get_fighter_id (LW6KER_MAP_STATE * map_state,
 	  fighter_id);
 };
 
+extern LW6KER_FIGHTER *lw6ker_map_state_get_fighter_safe (LW6KER_MAP_STATE *
+							  map_state,
+							  LW6SYS_INT32 layer,
+							  LW6SYS_INT32 x,
+							  LW6SYS_INT32 y);
 /*
  * Carefull with this one, there must really be a fighter
  * or it segfaults directly.
  */
 static inline LW6KER_FIGHTER *
-lw6ker_map_state_get_fighter (LW6KER_MAP_STATE * map_state,
-			      LW6SYS_INT32 layer, LW6SYS_INT32 x,
-			      LW6SYS_INT32 y)
+lw6ker_map_state_get_fighter_unsafe (LW6KER_MAP_STATE * map_state,
+				     LW6SYS_INT32 layer, LW6SYS_INT32 x,
+				     LW6SYS_INT32 y)
 {
   return (&
 	  (map_state->armies.
