@@ -1,11 +1,11 @@
 /*
 Liquid War 6 is a unique multiplayer wargame.
-Copyright (C)  2005, 2006  Christian Mauduit <ufoot@ufoot.org>
+Copyright (C)  2005, 2006, 2007  Christian Mauduit <ufoot@ufoot.org>
 
-This program is free software; you can redistribute it and/or
-modify it under the terms of the GNU General Public License
-as published by the Free Software Foundation; either version 2
-of the License, or (at your option) any later version.
+This program is free software; you can redistribute it and/or modify
+it under the terms of the GNU General Public License as published by
+the Free Software Foundation, either version 3 of the License, or
+(at your option) any later version.
 
 This program is distributed in the hope that it will be useful,
 but WITHOUT ANY WARRANTY; without even the implied warranty of
@@ -13,8 +13,8 @@ MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 GNU General Public License for more details.
 
 You should have received a copy of the GNU General Public License
-along with this program; if not, write to the Free Software
-Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
+along with this program.  If not, see <http://www.gnu.org/licenses/>.
+
 
 Liquid War 6 homepage : http://www.gnu.org/software/liquidwar6/
 Contact author        : ufoot@ufoot.org
@@ -54,10 +54,12 @@ typedef struct LW6_GLOBAL_STRUCT
   void *cfg_context;
   LW6GFX_BACKEND *gfx_backend;
   LW6SND_BACKEND *snd_backend;
+  void *net_context;
   int cfg_initialized;
   int gfx_initialized;
   int snd_initialized;
   int con_initialized;
+  int net_initialized;
   int argc;
   char **argv;
   LW6_SMOB_TYPES smob_types;
