@@ -1,11 +1,11 @@
 /*
   Liquid War 6 is a unique multiplayer wargame.
-  Copyright (C)  2005, 2006  Christian Mauduit <ufoot@ufoot.org>
+  Copyright (C)  2005, 2006, 2007  Christian Mauduit <ufoot@ufoot.org>
 
-  This program is free software; you can redistribute it and/or
-  modify it under the terms of the GNU General Public License
-  as published by the Free Software Foundation; either version 2
-  of the License, or (at your option) any later version.
+  This program is free software; you can redistribute it and/or modify
+  it under the terms of the GNU General Public License as published by
+  the Free Software Foundation, either version 3 of the License, or
+  (at your option) any later version.
 
   This program is distributed in the hope that it will be useful,
   but WITHOUT ANY WARRANTY; without even the implied warranty of
@@ -13,8 +13,8 @@
   GNU General Public License for more details.
 
   You should have received a copy of the GNU General Public License
-  along with this program; if not, write to the Free Software
-  Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
+  along with this program.  If not, see <http://www.gnu.org/licenses/>.
+  
 
   Liquid War 6 homepage : http://www.gnu.org/software/liquidwar6/
   Contact author        : ufoot@ufoot.org
@@ -57,7 +57,7 @@ static int
 test_new_free ()
 {
   int ret = 1;
-  LW6MAP_MAP *map;
+  LW6MAP_MAP *map = NULL;
   FUNCTION_BEGIN;
 
   {
@@ -117,6 +117,9 @@ test_read ()
 	{
 	  ret = 0;
 	}
+
+      lw6map_param_clear (&param);
+
       LW6SYS_FREE (path);
     }
   else
@@ -139,7 +142,8 @@ main (int argc, char *argv[])
 
   ret = test_dir () && test_new_free () && test_read ();
 
-  ret = ret && lw6sys_check_malloc_free_count ();
+  ret = lw6sys_check_malloc_free_count () && ret;
+  ret = lw6sys_check_thread_count () && ret;
 
   return (!ret);
 }
