@@ -1,11 +1,11 @@
 /*
   Liquid War 6 is a unique multiplayer wargame.
-  Copyright (C)  2005, 2006  Christian Mauduit <ufoot@ufoot.org>
+  Copyright (C)  2005, 2006, 2007  Christian Mauduit <ufoot@ufoot.org>
 
-  This program is free software; you can redistribute it and/or
-  modify it under the terms of the GNU General Public License
-  as published by the Free Software Foundation; either version 2
-  of the License, or (at your option) any later version.
+  This program is free software; you can redistribute it and/or modify
+  it under the terms of the GNU General Public License as published by
+  the Free Software Foundation, either version 3 of the License, or
+  (at your option) any later version.
 
   This program is distributed in the hope that it will be useful,
   but WITHOUT ANY WARRANTY; without even the implied warranty of
@@ -13,8 +13,8 @@
   GNU General Public License for more details.
 
   You should have received a copy of the GNU General Public License
-  along with this program; if not, write to the Free Software
-  Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
+  along with this program.  If not, see <http://www.gnu.org/licenses/>.
+  
 
   Liquid War 6 homepage : http://www.gnu.org/software/liquidwar6/
   Contact author        : ufoot@ufoot.org
@@ -47,15 +47,7 @@ lw6sys_read_file_content (char *filename)
       if (size >= 0)
 	{
 	  fseek (f, 0, SEEK_SET);
-	  file_content = LW6SYS_MALLOC (size + 1);
-	  /*
-	   * Do not suppress this memset 0, it's responsible for
-	   * putting a traling '\0'. Doing a simple affectation on
-	   * the last byte would work to, but this is even safer,
-	   * this way even if we half read the file, the non-read
-	   * stuff will be filled with zeros.
-	   */
-	  memset (file_content, 0, size + 1);
+	  file_content = LW6SYS_CALLOC (size + 1);
 	  if (file_content)
 	    {
 	      clearerr (f);
