@@ -1,11 +1,11 @@
 /*
   Liquid War 6 is a unique multiplayer wargame.
-  Copyright (C)  2005, 2006  Christian Mauduit <ufoot@ufoot.org>
+  Copyright (C)  2005, 2006, 2007  Christian Mauduit <ufoot@ufoot.org>
 
-  This program is free software; you can redistribute it and/or
-  modify it under the terms of the GNU General Public License
-  as published by the Free Software Foundation; either version 2
-  of the License, or (at your option) any later version.
+  This program is free software; you can redistribute it and/or modify
+  it under the terms of the GNU General Public License as published by
+  the Free Software Foundation, either version 3 of the License, or
+  (at your option) any later version.
 
   This program is distributed in the hope that it will be useful,
   but WITHOUT ANY WARRANTY; without even the implied warranty of
@@ -13,8 +13,8 @@
   GNU General Public License for more details.
 
   You should have received a copy of the GNU General Public License
-  along with this program; if not, write to the Free Software
-  Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
+  along with this program.  If not, see <http://www.gnu.org/licenses/>.
+  
 
   Liquid War 6 homepage : http://www.gnu.org/software/liquidwar6/
   Contact author        : ufoot@ufoot.org
@@ -145,3 +145,62 @@ lw6sys_new_sprintf (char *fmt, ...)
 
   return ret;
 }
+
+int
+lw6sys_str_is_blank (char *str)
+{
+  int ret = 1;
+  char *pos;
+
+  pos = str;
+  while (ret && *pos)
+    {
+      /*
+       * A simple >32 test is enough to exclude blanks (' ')
+       * but will also get rid of '\t', '\n', '\r', and in
+       * a general all characters but real stuff.
+       */
+      if ((*pos) > 32)
+	{
+	  ret = 0;
+	}
+      pos++;
+    }
+
+  return ret;
+}
+
+int
+lw6sys_skip_blanks (char **str_ptr)
+{
+  int ret = 0;
+
+  while ((**str_ptr) == ' ' || (**str_ptr) == '\t')
+    {
+      ret = 1;
+      (*str_ptr)++;
+    }
+
+  return ret;
+}
+
+/*
+ * Used to clean up some strings, for instance if they
+ * come from the network, we don't necessarly want system
+ * chars to be displayed on the console.
+ */
+void
+lw6sys_str_cleanup (char *str)
+{
+  char *pos;
+
+  pos = str;
+  while (*pos)
+    {
+      if ((*pos) < 32)
+	{
+	  (*pos) = ' ';
+	}
+      pos++;
+    }
+}
